******************************************************************************
*** FUNCTION MFEMEAN is used to calculate the mean energy of a decay product
*** when a moving particle decays. E0 and M0 are the energy and mass of
*** the moving particle and M1 and M2 are the masses of the decay products.
*** It is the mean energy of M1 that is returned. All energies and masses
*** should be given in GeV.
******************************************************************************

      real*8 function MFemean(e0,m0,m1,m2)
      implicit none
      include 'MFCom.h'

c------------------------ variables ------------------------------------

      real*8 e0,m0,m1,m2,m00,e00
      real*8 e1cm

c-----------------------------------------------------------------------

      m00=m0
      e00=e0
c...Take care of slight numerical inaccuracy problems
      if (m00.lt.(m1+m2)) then
        if (m00.gt.0.99*(m1+m2)) then
          m00=(m1+m2)*1.0001
          if (e0.lt.m00) e00=m00
        else
          write(*,*) 'ERROR in MFemean: A particle with mass ',m0
          write(*,*) 'is let to decay to two particles with mass ',
     &      m1,' and ',m2
          write(*,*) 'which is not energetically allowed.'
          write(*,*) 'Model: ',MFtag
          write(*,*) 'Program is stopped.'
          stop
        endif
      endif

      e1cm=(m00**2+m1**2-m2**2)/(2.0d0*m00)
      MFemean=e00/m00*e1cm           ! Mean energy
c      MFemean=e0/m0*sqrt(e1cm**2+(e0**2-m0**2)/e0**2*
c     +  (e1cm**2-m1**2)/3.0)      ! Mean root square energy

      end

