      program flx2ann
      implicit none
c_______________________________________________________________________
c
c  Program to find how limits derived with a given energy
c  threshold converts to limits of a given other energy threshold.
c  Author: Joakim Edsjo
c  Date: 1999-12-03
c
c=======================================================================
c------------------------------------------------------------ Functions

      real*8 MFphi
      real murang

c------------------------------------------------------------ Variables

      real*8 mneu,thmax,denscorr
      real*8 eth0,phi0,eth1,phi1,cf,phi0noth,phi1noth,cf2,thmax0
      integer ch,flxk,istat,i,flxk0,flxk1
      character*2 wh
      character*4 type(6)
      character*80 filename
      data type/'soft','soft','soft','hard','hard','hard'/
      data denscorr/0.92d0/  ! correction for sims at 1 g/cm^3

c---------------------------------------------------------------- Setup

c...Chose type of distributions here
c...101 differential flux of neutrinos
c...102 differentiel source function of muons in the ice
c...  - use for putting muons out in a volume
c...103 differential flux of muons in the ice
c...  - use for putting muons out on the surface of the detector
c...  - includes energy loss and multiple Coulomb scattering
      flxk=3 ! Integrated flux above a given threshold and
             ! within a given angular window


c      do i=0,1000
c        eth0=dble(i)*dble(250.0d0)/dble(1000.0d0)
c        phi0 = MFphi(250.0d0,eth0,29.99d0,5,'ea',3,istat)
c        write(*,*) eth0,phi0
c      enddo
c      stop

c----------------------------------------------------------------------
      write(*,*)
      write(*,*) '                 FLX2ANN 1.01'
      write(*,*) '       (based on DarkSusy, version 3.07)'
      write(*,*) ' '
      write(*,*) '       A program to convert from a flux'
      write(*,*) '           to an annihilation rate'
      write(*,*) '    from WIMP annihilation in the Earth/Sun.'
      write(*,*) ' '
      write(*,*) '               December 3, 1999'
      write(*,*) '                   J. Edsjo'   
      write(*,*) '                edsjo@physto.se'
      write(*,*) ' '

      write(*,*) ' '
      write(*,*) 'Enter filename for results (''none'' for no file)'
      read(*,'(A)') filename
      write(*,*) filename

      if (filename.ne.'none') then
        open(unit=15,file=filename,status='new',form='formatted')
        write(15,98) 
        write(15,99)
 98     format('#','Flux (km^-2 yr^-1) * ConvFact -> AnnRate (s^-1)')
 99     format('#','...mx...',1x,'.wh.',1x,
     &    '.ch.',1x,'type',1x,'..thmax.',1x,'..eth0..',1x,'flxk0',1x,
     &    '..ConvFact..')
      endif

 10   write(*,*)
      write(*,*) 'Enter Neutralino mass [GeV] (0 to quit):'
      read(*,*) mneu
      write(*,*) mneu
      if (mneu.eq.0.0d0) then
        close(15)
        stop
      endif

      write(*,*) 'Annihilation in the Earth(''ea'') or the Sun(''su''):'
      read(*,'(a)') wh
      write(*,*) wh

      write(*,*) 'Annihilation channel?'
      write(*,*) '  1 = c c-bar'
      write(*,*) '  2 = b b-bar'
      write(*,*) '  3 = t t-bar'
      write(*,*) '  4 = tau^+ tau^-'
      write(*,*) '  5 = W^+ W^-'
      write(*,*) '  6 = Z^0 Z^0'
      read(*,*) ch
      write(*,*) ch


      write(*,*) 'Enter energy threshold:'
      read(*,*) eth0
      write(*,*) eth0

      write(*,*) 'Threshold on muon source (2) or flux (3)?'
      read(*,*) flxk0
      write(*,*) flxk0

      write(*,*) 'Enter opening angle (half-aperture) in degrees:'
      read(*,*) thmax0
      write(*,*) thmax0


      phi0 = MFphi(mneu,eth0,thmax0,ch,wh,flxk0,istat)

c...First calculate conversion ann-rate -> flux
      cf=3.16d13                ! m^-2 s^-1 -> km^-2 yr^-1
     &  *phi0                   ! MFphi
     &  *1.0d-30                ! factor in MFphi

      if (flxk0.eq.2) then
         cf=cf*1000.0d0         ! Another m^-1 -> km^-1 for the source function
         cf=cf*denscorr         ! tables for dens = 1 g/cm^3
      endif

c...then invert it
      cf=1.0d0/cf


      if (filename.ne.'none') then
        write(15,100) mneu,wh,ch,type(ch),
     &    thmax,eth0,flxk0,cf
 100    format(1x,F8.2,1x,A4,1x,I4,1x,A4,1x,F8.2,1x,F8.2,1x,I5,1x,
     &    E12.6)
      endif

      write(*,*) ' '
      write(*,*) 'RESULTS'
      write(*,*) '======='
      write(*,*) ' '
      write(*,*) '  mneu  = ',mneu
      write(*,*) '  wh    = ',wh
      write(*,*) '  ch    = ',ch
      write(*,*) '  eth0  = ',eth0
      write(*,*) '  type0 = ',flxk0
      write(*,*) '     ====> Conversion factor = ',cf
      write(*,*) 'Multiply your flux limit in km^-2 yr^-1 with'
      write(*,*) 'the conversion factor to get a limit on the'
      write(*,*) 'annihilation rate in ann s^-1.'


      goto 10 

      end

